==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesMi.php <==
<?php
/** Maori (Māori)
 *
 * @ingroup Language
 * @file
 *
 * @author Kiharoa
 */

$messages = array(
# Dates
'sunday'    => 'Rātapu',
'monday'    => 'Rāhina',
'tuesday'   => 'Rātū',
'wednesday' => 'Rāapa',
'thursday'  => 'Rāpare',
'friday'    => 'Rāmere',
'saturday'  => 'Rāhoroi',
'january'   => 'Kohi-tātea',
'february'  => 'Hui-tanguru',
'march'     => 'Poutū-te-rangi',
'april'     => 'Paenga-whāwhā',
'may_long'  => 'Haratua',
'june'      => 'Pipiri',
'july'      => 'Hōngongoi',
'august'    => 'Here-turi-kōkā',
'september' => 'Mahuru',
'october'   => 'Whiringa-ā-nuku',
'november'  => 'Whiringa-ā-rangi',
'december'  => 'Hakihea',

'cancel'         => 'Whakakore',
'qbspecialpages' => 'Whārangi motuhake',
'mytalk'         => 'Karere mōku',
'navigation'     => 'Huarahi',

'help'             => 'Whakamārama',
'search'           => 'Rapua',
'go'               => 'Haere',
'history'          => 'Kōrero Nehe',
'history_short'    => 'Tuhinga/kaituhi',
'printableversion' => 'Tāia',
'permalink'        => 'Hononga toitū',
'edit'             => 'Whakatika',
'delete'           => 'tangohia',
'protect'          => 'Whakangungua',
'talk'             => 'Kōrerorero',
'toolbox'          => 'Pouaka utauta',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'         => 'Mo {{SITENAME}}',
'currentevents'     => 'Kōrero',
'currentevents-url' => 'Project:Kōrero',
'mainpage'          => 'Hau Kāinga',
'portal'            => 'Tomokanga hapori',
'portal-url'        => 'Project:Tomokanga hapori',
'privacy'           => 'Tikanga tūmataiti',
'privacypage'       => 'Project:Tikanga tūmataiti',
'sitesupport'       => 'Koha',

'toc'     => 'Rārangi kōrero',
'showtoc' => 'whakakite',
'hidetoc' => 'hunaia',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'tuhi pānui',
'nstab-template' => 'papa tauira',
'nstab-help'     => 'Āwhina',
'nstab-category' => 'Wāhanga',

# Login and logout pages
'userlogout' => 'Whakarere',

# Edit pages
'savearticle' => 'Tiaki',
'showdiff'    => 'Tiro rerekētanga',

# Preferences page
'preferences' => 'Kōwhiringa',

# Recent changes
'recentchanges' => 'Rerekētanga hōu',
'hide'          => 'Hunaia',
'show'          => 'Whakaaturia',

# Recent changes linked
'recentchangeslinked' => 'Rerekētanga pū tahi',

# Upload
'upload' => 'Tuku atu',

# Random page
'randompage' => 'Tipihaere',

# Miscellaneous special pages
'allpages'     => 'Ngā whārangi katoa',
'specialpages' => 'Whārangi motuhake',
'move'         => 'Nekehia',

# Special:Allpages
'allpagessubmit' => 'Haere',

# Watchlist
'watchlist'   => 'Rārangi mātaki',
'mywatchlist' => 'Rārangi mātaki',
'watch'       => 'Mātaki',
'unwatch'     => 'kāti te mātaki',

# Contributions
'contributions' => 'Ngā mahi a tēnei mema',
'mycontris'     => 'āku mahi',

# What links here
'whatlinkshere' => 'Ngā hononga mai',

# Namespace 8 related
'allmessages' => 'Pānui pūnaha',

);

==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesMi.php <==
<?php
/** Maori (Māori)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Kiharoa
 * @author Sonia
 */

$messages = array(
# Dates
'sunday'    => 'Rātapu',
'monday'    => 'Rāhina',
'tuesday'   => 'Rātū',
'wednesday' => 'Rāapa',
'thursday'  => 'Rāpare',
'friday'    => 'Rāmere',
'saturday'  => 'Rāhoroi',
'january'   => 'Kohi-tātea',
'february'  => 'Hui-tanguru',
'march'     => 'Poutū-te-rangi',
'april'     => 'Paenga-whāwhā',
'may_long'  => 'Haratua',
'june'      => 'Pipiri',
'july'      => 'Hōngongoi',
'august'    => 'Here-turi-kōkā',
'september' => 'Mahuru',
'october'   => 'Whiringa-ā-nuku',
'november'  => 'Whiringa-ā-rangi',
'december'  => 'Hakihea',

'cancel'         => 'Whakakore',
'qbspecialpages' => 'Whārangi motuhake',
'mytalk'         => 'Karere mōku',
'navigation'     => 'Huarahi',

'help'             => 'Whakamārama',
'search'           => 'Rapua',
'go'               => 'Haere',
'history'          => 'Kōrero Nehe',
'history_short'    => 'Tuhinga/kaituhi',
'printableversion' => 'Tāia',
'permalink'        => 'Hononga toitū',
'edit'             => 'Whakatika',
'delete'           => 'tangohia',
'protect'          => 'Whakangungua',
'talkpagelinktext' => 'Kōrerohia',
'talk'             => 'Kōrerorero',
'toolbox'          => 'Pouaka utauta',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Mo {{SITENAME}}',
'currentevents'        => 'Kōrero',
'currentevents-url'    => 'Project:Kōrero',
'mainpage'             => 'Hau Kāinga',
'mainpage-description' => 'Hau Kāinga',
'portal'               => 'Tomokanga hapori',
'portal-url'           => 'Project:Tomokanga hapori',
'privacy'              => 'Tikanga tūmataiti',
'privacypage'          => 'Project:Tikanga tūmataiti',

'toc'     => 'Rārangi kōrero',
'showtoc' => 'whakakite',
'hidetoc' => 'hunaia',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'tuhi pānui',
'nstab-template' => 'papa tauira',
'nstab-help'     => 'Āwhina',
'nstab-category' => 'Wāhanga',

# Login and logout pages
'userlogout' => 'Whakarere',

# Edit pages
'savearticle' => 'Tiaki',
'showdiff'    => 'Tiro rerekētanga',

# Preferences page
'preferences' => 'Kōwhiringa',

# Recent changes
'recentchanges' => 'Rerekētanga hōu',
'hide'          => 'Hunaia',
'show'          => 'Whakaaturia',

# Recent changes linked
'recentchangeslinked' => 'Rerekētanga pū tahi',

# Upload
'upload' => 'Tuku atu',

# Random page
'randompage' => 'Tipihaere',

# Miscellaneous special pages
'move' => 'Nekehia',

# Special:AllPages
'allpages'       => 'Ngā whārangi katoa',
'allpagessubmit' => 'Haere',

# Watchlist
'watchlist'   => 'Rārangi mātaki',
'mywatchlist' => 'Rārangi mātaki',
'watch'       => 'Mātaki',
'unwatch'     => 'kāti te mātaki',

# Contributions
'contributions' => 'Ngā mahi a tēnei mema',
'mycontris'     => 'āku mahi',

# What links here
'whatlinkshere' => 'Ngā hononga mai',

# Namespace 8 related
'allmessages' => 'Pānui pūnaha',

# Special:SpecialPages
'specialpages' => 'Whārangi motuhake',

);
